@@ -120,14 +120,6 @@ def __serialize_request(request):
             },
         }
 
-        if request.content_type == 'application/json':
-            content = request.body.decode()
-            try:
-                content = json.loads(content)
-            except json.JSONDecodeError:
-                pass
-
-            result['POST'] = content
     except Exception:
         logger.exception('django-on-chain exception while serializing request object')
         result = request
